Struct tk_pool::queue::QueueError [] [src]

pub struct QueueError<V>(_);

Error returned by the sink, when underlying pool is closed

The error contains underlying item that was sent using start_send

Methods

impl<T> QueueError<T>
[src]

[src]

Return ownership of contained message