Struct tk_pool::queue::Pool
[−]
[src]
pub struct Pool<V, M> { /* fields omitted */ }Pool is an object you use to access a connection pool
Usually the whole logic of connection pool is spawned in another future. This object encapsulates a channel that is used to communicate with pool. This object also contains a clone of metrics collection object as it's very important to collect metrics at this side of a channel.